@@ -14,13 +14,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
 
 import torch
-from torch import nn
 import torch.nn.functional as F
+from torch import nn
 
 
 class ClsHead(nn.Module):
@@ -35,9 +33,7 @@ class ClsHead(nn.Module):
     def __init__(self, in_channels, class_dim, **kwargs):
         super(ClsHead, self).__init__()
         self.pool = nn.AdaptiveAvgPool2d(1)
-        self.fc = nn.Linear(
-            in_channels,
-            class_dim)
+        self.fc = nn.Linear(in_channels, class_dim)
 
     def forward(self, x):
         x = self.pool(x)
