@@ -14,24 +14,29 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import numpy as np
+import logging
 import os
-from torch.utils.data import Dataset
-from ucr.core.preprocess import preprocess
-import lmdb
+
 import cv2
+import lmdb
+import numpy as np
+from torch.utils.data import Dataset
+
+from ucr.core.preprocess import preprocess
+
+log = logging.getLogger(__name__)
 
 
 class LMDBDateSet(Dataset):
     def __init__(self, config, build_preprocess, logger):
         super(LMDBDateSet, self).__init__()
-        
-        batch_size = config['batch_size_per_card']
-        data_dir = config['data_dir']
-        self.do_shuffle = config['shuffle']
+
+        config["batch_size_per_card"]
+        data_dir = config["data_dir"]
+        self.do_shuffle = config["shuffle"]
 
         self.lmdb_sets = self.load_hierarchical_lmdb_dataset(data_dir)
-        logger.info("Initialize indexs of datasets:%s" % data_dir)
+        log.info("Initialize indexs of datasets:%s" % data_dir)
         self.data_idx_order_list = self.dataset_traversal()
         if self.do_shuffle:
             np.random.shuffle(self.data_idx_order_list)
@@ -40,7 +45,7 @@ class LMDBDateSet(Dataset):
     def load_hierarchical_lmdb_dataset(self, data_dir):
         lmdb_sets = {}
         dataset_idx = 0
-        for dirpath, dirnames, filenames in os.walk(data_dir + '/'):
+        for dirpath, dirnames, filenames in os.walk(data_dir + "/"):
             if not dirnames:
                 env = lmdb.open(
                     dirpath,
@@ -48,27 +53,33 @@ class LMDBDateSet(Dataset):
                     readonly=True,
                     lock=False,
                     readahead=False,
-                    meminit=False)
+                    meminit=False,
+                )
                 txn = env.begin(write=False)
-                num_samples = int(txn.get('num-samples'.encode()))
-                lmdb_sets[dataset_idx] = {"dirpath":dirpath, "env":env, \
-                    "txn":txn, "num_samples":num_samples}
+                num_samples = int(txn.get("num-samples".encode()))
+                lmdb_sets[dataset_idx] = {
+                    "dirpath": dirpath,
+                    "env": env,
+                    "txn": txn,
+                    "num_samples": num_samples,
+                }
                 dataset_idx += 1
         return lmdb_sets
-    
+
     def dataset_traversal(self):
         lmdb_num = len(self.lmdb_sets)
         total_sample_num = 0
         for lno in range(lmdb_num):
-            total_sample_num += self.lmdb_sets[lno]['num_samples']
+            total_sample_num += self.lmdb_sets[lno]["num_samples"]
         data_idx_order_list = np.zeros((total_sample_num, 2))
         beg_idx = 0
         for lno in range(lmdb_num):
-            tmp_sample_num = self.lmdb_sets[lno]['num_samples']
+            tmp_sample_num = self.lmdb_sets[lno]["num_samples"]
             end_idx = beg_idx + tmp_sample_num
             data_idx_order_list[beg_idx:end_idx, 0] = lno
-            data_idx_order_list[beg_idx:end_idx, 1] \
-                = list(range(tmp_sample_num))
+            data_idx_order_list[beg_idx:end_idx, 1] = list(
+                range(tmp_sample_num)
+            )
             data_idx_order_list[beg_idx:end_idx, 1] += 1
             beg_idx = beg_idx + tmp_sample_num
         return data_idx_order_list
@@ -77,7 +88,7 @@ class LMDBDateSet(Dataset):
         """get_img_data"""
         if not value:
             return None
-        imgdata = np.frombuffer(value, dtype='uint8')
+        imgdata = np.frombuffer(value, dtype="uint8")
         if imgdata is None:
             return None
         imgori = cv2.imdecode(imgdata, 1)
@@ -86,12 +97,12 @@ class LMDBDateSet(Dataset):
         return imgori
 
     def get_lmdb_sample_info(self, txn, index):
-        label_key = 'label-%09d'.encode() % index
+        label_key = "label-%09d".encode() % index
         label = txn.get(label_key)
         if label is None:
             return None
-        label = label.decode('utf-8')
-        img_key = 'image-%09d'.encode() % index
+        label = label.decode("utf-8")
+        img_key = "image-%09d".encode() % index
         imgbuf = txn.get(img_key)
         return imgbuf, label
 
@@ -99,12 +110,13 @@ class LMDBDateSet(Dataset):
         lmdb_idx, file_idx = self.data_idx_order_list[idx]
         lmdb_idx = int(lmdb_idx)
         file_idx = int(file_idx)
-        sample_info = self.get_lmdb_sample_info(self.lmdb_sets[lmdb_idx]['txn'],
-                                                file_idx)
+        sample_info = self.get_lmdb_sample_info(
+            self.lmdb_sets[lmdb_idx]["txn"], file_idx
+        )
         if sample_info is None:
             return self.__getitem__(np.random.randint(self.__len__()))
         img, label = sample_info
-        data = {'image': img, 'label': label}
+        data = {"image": img, "label": label}
         outs = preprocess(data, self.ops)
         if outs is None:
             return self.__getitem__(np.random.randint(self.__len__()))
