@@ -50,12 +50,8 @@ class TextSystem(object):
         self.text_classifier = infer_cls.TextClassifier(
             config["Classification"]
         )
-        self.save_csv = config["save_csv"]
-        self.save_image = config["save_image"]
         self.drop_score = config["drop_score"]
         self.merge_boxes = config["merge_boxes"]
-        self.return_type = config["return_type"]
-        self.verbose = config["verbose"]
         self.font_path = config["Recognition"]["font_path"]
 
         if self.merge_boxes:
@@ -109,10 +105,10 @@ class TextSystem(object):
             dst_img = np.rot90(dst_img)
         return dst_img
 
-    def perform_ocr(self, img, cls):
+    def perform_ocr(self, img, cls, verbose=False):
         ori_im = img.copy()
         dt_boxes, elapse = self.text_detector(img)
-        if self.verbose:
+        if verbose:
             print(
                 "\n------------------------dt_boxes num : {},\telapse : {:.3f}------------------------".format(
                     len(dt_boxes), elapse
@@ -131,7 +127,7 @@ class TextSystem(object):
 
         if cls:
             img_crop_list, _, elapse = self.text_classifier(img_crop_list)
-            if self.verbose:
+            if verbose:
                 print(
                     "------------------------cls num  : {},\telapse : {:.3f}------------------------".format(
                         len(img_crop_list), elapse
@@ -139,7 +135,7 @@ class TextSystem(object):
                 )
 
         rec_res, elapse = self.text_recognizer(img_crop_list)
-        if self.verbose:
+        if verbose:
             print(
                 "------------------------rec_res num  : {},\telapse : {:.3f}------------------------\n".format(
                     len(rec_res), elapse
@@ -181,6 +177,10 @@ class TextSystem(object):
         det=True,
         rec=True,
         cls=False,
+        return_type="df",
+        save_image=False,
+        save_tsv=True,
+        verbose=False,
     ):
         assert isinstance(input, (np.ndarray, list, str))
 
@@ -192,7 +192,7 @@ class TextSystem(object):
         elif o != "output":
             output = o  # output takes higher precedence than o
 
-        if self.save_csv or self.save_image:
+        if save_tsv or save_image:
             print(
                 "Saving prediction results in '{}' folder!\n".format(output),
                 flush=True,
@@ -262,16 +262,18 @@ class TextSystem(object):
                         continue
                 if det:
                     if rec:
-                        dt_boxes, rec_res = self.perform_ocr(img, cls)
+                        dt_boxes, rec_res = self.perform_ocr(
+                            img, cls, verbose=verbose
+                        )
                         if self.merge_boxes:
                             rec_res = rec_res[0:1]
 
-                        if self.return_type == "list":
+                        if return_type == "list":
                             value = [
                                 [box.tolist(), res]
                                 for box, res in zip(dt_boxes, rec_res)
                             ]
-                        elif self.return_type == "df" or self.save_csv:
+                        elif return_type == "df" or save_tsv:
                             info_list = [
                                 [
                                     int(box[0][0]),
@@ -292,14 +294,21 @@ class TextSystem(object):
                                     "Text",
                                 ],
                             )
-                            if self.save_csv:
-                                csv_out = os.path.join(output, 'csv')
-                                if not os.path.exists(csv_out):
-                                    os.makedirs(csv_out)
-                                csv_path = os.path.join(csv_out, "ocr_{}".format(key.split("/")[-1]))
-                                value.to_csv(csv_path + ".csv", index=False)
+                            if save_tsv:
+                                tsv_out = os.path.join(output, "tsv")
+                                if not os.path.exists(tsv_out):
+                                    os.makedirs(tsv_out)
+                                tsv_path = os.path.join(
+                                    tsv_out,
+                                    "ocr_{}".format(
+                                        os.path.basename(key.split("/")[-1])[0]
+                                    ),
+                                )
+                                value.to_csv(
+                                    tsv_path + ".tsv", sep="\t", index=False
+                                )
 
-                        if self.verbose:
+                        if verbose:
                             from tabulate import tabulate
 
                             headers = ["OCR Result", "Score"]
@@ -318,7 +327,7 @@ class TextSystem(object):
                                     )
                                 )
 
-                        if self.save_image:
+                        if save_image:
                             image = Image.fromarray(
                                 cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
                             )
@@ -336,30 +345,35 @@ class TextSystem(object):
                                 drop_score=self.drop_score,
                                 font_path=self.font_path,
                             )
-                            img_out = os.path.join(output, 'image')
+                            img_out = os.path.join(output, "image")
                             if not os.path.exists(img_out):
                                 os.makedirs(img_out)
                             img_path = os.path.join(
-                                img_out, "ocr_{}".format(key.split("/")[-1])
+                                img_out,
+                                "ocr_{}".format(
+                                    os.path.basename(key.split("/")[-1])[0]
+                                ),
+                            )
+                            cv2.imwrite(
+                                img_path + ".jpg", draw_img[:, :, ::-1]
                             )
-                            cv2.imwrite(img_path, draw_img[:, :, ::-1])
                             pbar.set_postfix_str(
                                 "Output Path: '{}'".format(img_path)
                             )
 
                     else:
                         dt_boxes, elapse = self.text_detector(img)
-                        if self.verbose:
+                        if verbose:
                             print(
                                 "\n------------------------dt_boxes num : {},\telapse : {:.3f}------------------------".format(
                                     len(dt_boxes), elapse
                                 )
                             )
                         if dt_boxes is not None:
-                            if self.return_type == "list":
+                            if return_type == "list":
                                 value = [box.tolist() for box in dt_boxes]
 
-                            elif self.return_type == "df" or self.save_csv:
+                            elif return_type == "df" or save_tsv:
                                 info_list = [
                                     [
                                         int(box[0][0]),
@@ -378,23 +392,37 @@ class TextSystem(object):
                                         "endY",
                                     ],
                                 )
-                                if self.save_csv:
-                                    csv_out = os.path.join(output, 'csv')
-                                    if not os.path.exists(csv_out):
-                                        os.makedirs(csv_out)
-                                    csv_path = os.path.join(csv_out, "ocr_{}".format(key.split("/")[-1]))
-                                    value.to_csv(csv_path + ".csv", index=False)
+                                if save_tsv:
+                                    tsv_out = os.path.join(output, "tsv")
+                                    if not os.path.exists(tsv_out):
+                                        os.makedirs(tsv_out)
+                                    tsv_path = os.path.join(
+                                        tsv_out,
+                                        "ocr_{}".format(
+                                            os.path.basename(
+                                                key.split("/")[-1]
+                                            )[0]
+                                        ),
+                                    )
+                                    value.to_csv(
+                                        tsv_path + ".tsv",
+                                        sep="\t",
+                                        index=False,
+                                    )
 
-                            if self.save_image:
+                            if save_image:
                                 src_im = draw_text_det_res(dt_boxes, img)
-                                
-                                img_out = os.path.join(output, 'image')
+
+                                img_out = os.path.join(output, "image")
                                 if not os.path.exists(img_out):
                                     os.makedirs(img_out)
                                 img_path = os.path.join(
-                                    img_out, "det_{}".format(key.split("/")[-1])
+                                    img_out,
+                                    "det_{}".format(
+                                        os.path.basename(key.split("/")[-1])[0]
+                                    ),
                                 )
-                                cv2.imwrite(img_path, src_im)
+                                cv2.imwrite(img_path + ".jpg", src_im)
                                 pbar.set_postfix_str(
                                     "Output Path: '{}'".format(img_path)
                                 )
@@ -409,7 +437,7 @@ class TextSystem(object):
             if cls:
                 img, cls_res, _ = self.text_classifier(img)
                 if not rec:
-                    if self.verbose:
+                    if verbose:
                         cls_list = [
                             [k, v[0], v[1]]
                             for k, v in zip(list(rec_dict.keys()), cls_res)
@@ -426,8 +454,8 @@ class TextSystem(object):
                             tabulate(cls_list, headers, tablefmt="fancy_grid")
                         )
 
-                    if self.save_image:
-                        img_out = os.path.join(output, 'image')
+                    if save_image:
+                        img_out = os.path.join(output, "image")
                         if not os.path.exists(img_out):
                             os.makedirs(img_out)
                         output_names = [
@@ -446,7 +474,7 @@ class TextSystem(object):
                     return cls_output
             if rec:
                 rec_res, _ = self.text_recognizer(img)
-                if self.verbose:
+                if verbose:
                     rec_list = [
                         [k, v[0], v[1]]
                         for k, v in zip(list(rec_dict.keys()), rec_res)
@@ -457,8 +485,8 @@ class TextSystem(object):
                     headers = ["File Name", "Recognition Result", "Score"]
                     print(tabulate(rec_list, headers, tablefmt="fancy_grid"))
 
-                if self.save_image:
-                    img_out = os.path.join(output, 'image')
+                if save_image:
+                    img_out = os.path.join(output, "image")
                     if not os.path.exists(img_out):
                         os.makedirs(img_out)
                     output_names = [
@@ -516,7 +544,17 @@ def main(args):
     text_sys = TextSystem(config)
 
     input = hydra.utils.to_absolute_path(config["input"])
-    _ = text_sys(input)
+    _ = text_sys(
+        input,
+        output=hydra.utils.to_absolute_path(config["output"]),
+        det=config["det"],
+        rec=config["rec"],
+        cls=config["cls"],
+        return_type=config["return_type"],
+        save_image=config["save_image"],
+        save_tsv=config["save_tsv"],
+        verbose=config["verbose"],
+    )
 
 
 if __name__ == "__main__":
