@@ -46,7 +46,7 @@ def print_version() -> None:
     """Prints version information of rasa tooling and python."""
 
     print(
-        "UCR Version      :          0.2.13"
+        "UCR Version      :          0.2.14"
     )  # TODO: Change this to update automatically
     print(f"Python Version    :         {platform.python_version()}")
     print(f"Operating System  :         {platform.platform()}")
@@ -100,14 +100,18 @@ def parse_args(mMain=True, add_help=True):
         predict_parser.add_argument(
             "--force_download", type=str2bool, default=False
         )
-        predict_parser.add_argument("-o", "--output", type=str, default="output")
+        predict_parser.add_argument(
+            "-o", "--output", type=str, default="output"
+        )
         predict_parser.add_argument("-d", "--device", type=str, default="cuda")
         predict_parser.add_argument("-l", "--lang", type=str, default="ch_sim")
-        predict_parser.add_argument("--save_csv", type=str2bool, default=True)
-        predict_parser.add_argument("--save_image", type=str2bool, default=False)
+        predict_parser.add_argument("--save_tsv", type=str2bool, default=True)
+        predict_parser.add_argument(
+            "--save_image", type=str2bool, default=False
+        )
         predict_parser.add_argument("--backend", type=str, default="torch")
         predict_parser.add_argument("--type", type=str, default="mobile")
-        predict_parser.add_argument("--return_type", type=str, default=None)
+        predict_parser.add_argument("--return_type", type=str, default="df")
         predict_parser.add_argument(
             "--system_overrides", nargs="+", type=str, default=[]
         )
@@ -175,13 +179,9 @@ def parse_args(mMain=True, add_help=True):
             device="cuda",
             l="ch_sim",
             lang="ch_sim",
-            save_image=False,
-            save_csv=True,
             type="mobile",
             backend="torch",
-            return_type=None,
             system_overrides=[],
-            verbose=False,
             det_algorithm="CRAFT",
             det_config_name="infer_det",
             det_model_location=None,
@@ -225,7 +225,7 @@ class UCR(infer_system.TextSystem):
         lang = args.l
         if args.lang != "ch_sim":
             lang = args.lang
-            if lang != "ch_sim":
+            if args.l != "ch_sim":
                 print(
                     f'WARNING: "l (={args.l})" argument is superseded by "lang (={args.lang})" argument! l=lang={lang}'
                 )
@@ -233,7 +233,7 @@ class UCR(infer_system.TextSystem):
         device = args.d
         if args.device != "cuda":
             device = args.device
-            if device != "cuda":
+            if args.d != "cuda":
                 print(
                     f'WARNING: "d (={args.d})" argument is superseded by "device (={args.device})" argument! d=device={device}'
                 )
@@ -390,15 +390,6 @@ class UCR(infer_system.TextSystem):
         config["Detection"] = config_det
         config["Recognition"] = config_rec
         config["Classification"] = config_cls
-        
-        config["save_csv"] = args.save_csv
-        config["save_image"] = args.save_image
-        config["verbose"] = args.verbose
-        config["return_type"] = (
-            args.return_type
-            if args.return_type
-            else config["return_type"]
-        )
 
         super().__init__(config)
 
@@ -410,20 +401,43 @@ class UCR(infer_system.TextSystem):
         det=True,
         rec=True,
         cls=False,
+        return_type="df",
+        save_image=False,
+        save_tsv=True,
+        verbose=False,
     ):
-        return super().__call__(input, output, o, det, rec, cls)
+        return super().__call__(
+            input,
+            output,
+            o,
+            det,
+            rec,
+            cls,
+            return_type,
+            save_image,
+            save_tsv,
+            verbose,
+        )
 
 
 def test_cli(args):
+    args.save_tsv = False
+    args.save_image = False
     ocr_engine = UCR(**(args.__dict__))
     result = ocr_engine.predict(
-        os.path.join(__dir__,'utils/imgs/en3.jpg'),
+        os.path.join(__dir__, "utils/imgs/en3.jpg"),
         det=True,
         rec=True,
         cls=True,
+        return_type="df",
+        save_image=False,
+        save_tsv=True,
+        verbose=False,
     )
     if result is not None:
-        print(f"\n------------------------All tests passed! Success!------------------------")
+        print(
+            "\n------------------------All tests passed! Success!------------------------"
+        )
 
 
 def predict_cli(args):
@@ -434,6 +448,10 @@ def predict_cli(args):
         det=args.det,
         rec=args.rec,
         cls=args.cls,
+        return_type="df",
+        save_image=False,
+        save_tsv=True,
+        verbose=False,
     )
     if result is not None:
         for k, v in result.items():
@@ -448,6 +466,8 @@ def main():
     try:
         if hasattr(cmdline_arguments, "input"):
             cmdline_arguments.func(cmdline_arguments)
+        elif hasattr(cmdline_arguments, "lang"):
+            cmdline_arguments.func(cmdline_arguments)
         elif hasattr(cmdline_arguments, "version"):
             print_version()
         else:
